local AceGUI = LibStub("AceGUI-3.0")

--------------------------
-- Spacer API
--
-- :SetImage(path,...)
--    same as Label:SetImage
--
-- :SetImageSize(w,h)
--    same as Label:SetImageSize
--
-- Because the whole point is to take up space, the most-used functions will
-- probably be the sizing routines from the base widget API.
--
-- farmbuyer
--------------------------
do
	local Type = "Spacer"
	local Version = 1

	local function OnAcquire(self)
		self:SetHeight(110)
		self:SetWidth(110)
		self:SetImage(nil)
	end

	local function OnRelease(self)
		self.frame:ClearAllPoints()
		self.frame:Hide()
	end

	local function SetImage(self, path, ...)
		local space = self.space

        space:SetTexture(path or "Interface\\GLUES\\COMMON\\Glue-Tooltip-Background")
        local n = select('#', ...)
        if n == 4 or n == 8 then
            space:SetTexCoord(...)
        end
	end

	local function SetImageSize(self, width, height)
		self.frame:SetWidth(width)
		self.frame:SetHeight(height)
	end

	local function Constructor()
		local frame = CreateFrame("Frame",nil,UIParent)
		local self = {}
		self.type = Type

		self.OnRelease = OnRelease
		self.OnAcquire = OnAcquire
		self.SetImage = SetImage
		self.SetImageSize = SetImageSize

		self.frame = frame
		frame.obj = self

		frame:SetHeight(110)
		frame:SetWidth(110)
		frame:EnableMouse(true)

		local space = frame:CreateTexture(nil,"BACKGROUND")
		self.space = space
		space:SetAllPoints(frame)
        space:SetTexture("Interface\\GLUES\\COMMON\\Glue-Tooltip-Background")
		space:SetBlendMode("ADD")

		AceGUI:RegisterAsWidget(self)
		return self
	end

	AceGUI:RegisterWidgetType(Type,Constructor,Version)
end

